import { createWebHistory, createRouter } from "vue-router";
import HelloWorld from "@/components/HelloWorld.vue";
import AdminLogin from "@/components/admin/AdminLogin.vue";
import AdminSignup from "@/components/admin/AdminSignup.vue";
import AdminUsersList from "@/components/admin/users/AdminUsersList.vue";
import AdminUsersCreate from "@/components/admin/users/AdminUsersCreate.vue";
import AdminUsersForm from "@/components/admin/users/AdminUsersForm.vue";

import admin from '@/store/admin/index.js'

const routes = [
    {
        path: "/",
        name: "Home",
        component: HelloWorld,
    },
    {
        path: "/admin/login",
        name: "AdminLogin",
        component: AdminLogin,
    },
    {
        path: "/admin/signup",
        name: "AdminSignup",
        component: AdminSignup,
    },
    {
        path: "/admin/users",
        name: "AdminUsersList",
        component: AdminUsersList,
        meta: {
            requiresAuth: true,
        },
    },
    {
        path: '/admin/users/new',
        name: 'AdminUsersCreate',
        component: AdminUsersCreate,
        meta: {
            requiresAuth: true,
        },
    },
    {
        path: '/admin/users/:id',
        name: 'AdminUsersForm',
        component: AdminUsersForm,
        meta: {
            requiresAuth: true,
        },
    },
];

const router = createRouter({
    history: createWebHistory(),
    routes,
});

router.beforeEach((to, from, next) => {
    const user = admin.getters.getUser;

    if ((to.name == 'AdminLogin' || to.name == 'AdminSignup') && user !== null && !to.params.unauthorized) {
        next({ name: 'AdminUsersList' });
        return;
    }

    if (!to.meta.requiresAuth) {
        next();
        return;
    }

    if (user === null) {
        next({ name: 'AdminLogin' });
        return;
    }

    next();
});

export default router;
